@@ -227,15 +227,15 @@ bool CCECAdapterMessage::is_error(void) const
     code == MSGCODE_TRANSMIT_FAILED_TIMEOUT_LINE);
 }
 
-void CCECAdapterMessage::push_escaped(int16_t byte)
+void CCECAdapterMessage::push_escaped(uint8_t byte)
 {
   if (byte >= MSGESC && byte != MSGSTART)
   {
     push_back(MSGESC);
-    push_back((uint8_t) (byte - ESCOFFSET));
+    push_back(byte - ESCOFFSET);
   }
   else
-    push_back((uint8_t) byte);
+    push_back(byte);
 }
 
 CAdapterCommunication::CAdapterCommunication(CLibCEC *controller) :
